MonotonicDimension — csdmpy 0.1.1 documentation

# MonotonicDimension

## Generalized Class

Dimension

### Description

A monotonic dimension is a quantitative dimension where the coordinates along the dimension are explicitly defined and, unlike a LinearDimension, may not be derivable from the ordered array of indexes along the dimension. Let \(\mathbf{A}_k\) be an ordered set of strictly ascending or descending physical quantities and \(o_k\), the origin offset along the \(k^{th}\) dimension, then the coordinates, \(\mathbf{X}_k\), and the absolute coordinates, \(\mathbf{X}_k^\mathrm{abs}\), along a monotonic dimension follow

\[\begin{split}\begin{align} \mathbf{X}_k &= \mathbf{A}_k\\ \mathbf{X}_k^\mathrm{abs} &= \mathbf{X}_k + o_k \mathbf{1}, \end{align}\end{split}\]

where \(\mathbf{1}\) is an array of ones.

### Attributes

Name | Type | Description
--- | --- | ---
coordinates | [ScalarQuantity, ScalarQuantity, … ] | An array of strictly ascending or descending ScalarQuantity.
origin_offset | ScalarQuantity | The origin offset, \(o_k\), of the dimension.
quantity_name | String | The quantity name associated with the physical quantities describing the dimension.
period | ScalarQuantity | The period of the dimension.
reciprocal | ReciprocalDimension | The ReciprocalDimension object.

### Example

The following MonotonicDimension object,

    {
        "type": "monotonic",
        "coordinates": ["1 µs", "10 µs", "100 µs", "1 ms", "10 ms", "100 ms", "1 s", "10 s"]
    }

will generate a dimension where coordinates \(\mathbf{X}_k\) are

    [1 µs, 10 µs, 100 µs, 1 ms, 10 ms, 100 ms, 1 s, 10 s]